library(ggplot2)
library(dplyr)
library(reshape2)
library(tidyr)

###############################################################
###############################################################
#### FOR THE FINAL REPORT
#### "Potential damage to habitat from fishing gear" and "gear footprint" are weighted. 
  # check how_much_weight_exp, how_much_weight_sens, higher_weight_exposure, exclude_gear, write.csv
###############################################################
###############################################################


###############################################################
### PREP THE INPUT DATA
###############################################################

mypath <- "~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Input files/Round_Final"
#mypath <- "/Users/joe/Desktop/Jameal/Input files/Round_Final"
setwd(mypath)

# identify csv files
mylist <- list.files(mypath,pattern = ".csv")

# choose csv files to use
##### NOTE YOU MAY NEED TO CHANGE THE VALUES CONTAINED WITHIN THE BRACKETS IF THERE ARE MORE OR LESS THAN 27 INPUT .CSV'S #####
scoreslist <- mylist[c(1:27)] #2:27, length(mylist)

# change to FALSE if Gear footprint is included in the calculation
exclude_gear = FALSE

###############################################################

###############################################################
### READ IN DATA AND COMPILE SCORES
### SEPARATE IF STATEMENTS FOR TARGET, BYCATCH, AND HABITAT

df.out <- c() 
#df.out2 <- c()

# begin for loop for each csv file
for(i in 1:length(scoreslist)){

  # read in input file i
  df.tmp <- read.csv(scoreslist[i], header=TRUE)
  
  # truncate input file to get rid of NAs and blank cells
  df.tmp <- df.tmp[!apply(is.na(df.tmp) | df.tmp == "", 1, all),]
  df.tmp <- df.tmp[,!apply(is.na(df.tmp) | df.tmp == "", 2, all)]
  
  # IF SCORE = 0, ASSUME THAT FISHERY DOES NOT INTERACT WITH THAT BYCATCH OR HABITAT GROUP AND REASSIGN THE SCORE AS NA
  df.tmp$Score <- ifelse(df.tmp$Score == 0, NA, df.tmp$Score)
  
  ###############################################################
  # COMPILE WEIGHTED AVERAGE SCORES
  # USE IF STATEMENTS TO ASSIGN which attributes receive most of the weight, how much weight
  # ignore warning messages about if(df.tmp$Focal.component == "xxxx")
  ###############################################################
  
  ###############################################################
  # TARGET
  # all attributes weighted equally
  ###############################################################
  if(df.tmp$Focal.component == "Target"){ 
    df.tmp$Weighting <- NA
    how_much_weight <- 1
    df.tmp$Attribute.weighting <- how_much_weight
    
    # estimate average exposure and sensitivity scores for each ecosystem group, including baseline attributes
    df.tmp2 <-
      as.data.frame(
        df.tmp %>%
          group_by(Expert, Focal.component, Ecosystem.group, Fishery, Axis, Weighting) %>%
          summarise(
            Weighted.Mean = weighted.mean(Score, Attribute.weighting, na.rm=TRUE),
            Weighted.Data.Quality = weighted.mean(Data.Quality, Attribute.weighting, na.rm=TRUE)
            )
      )
    }
  ###############################################################
  
  ###############################################################
  # BYCATCH 
  # higher weight for Exposure attribute Magnitude and Sensitivity attribute ReleaseMortality
  ###############################################################
  
  if(df.tmp$Focal.component == "Bycatch"){
    
    df.tmp$Axis[which(df.tmp$Attribute=="Current status")] <- "Sensitivity"
    
    num.exp.attributes <- length(unique( subset(df.tmp, Axis == "Exposure")$Attribute))
    num.sens.attributes <- length(unique( subset(df.tmp, Axis == "Sensitivity")$Attribute))
    
    ###############################################################
    # THESE ARE ACTUALLY BEING USED TO GIVE 50% OF THE WEIGHT FOR THE EXPOSURE AND SENSITIVITY SCORES TO THESE ATTRIBUTES
    higher_weight_exposure <- "Magnitude"
    higher_weight_sensitivity <- "Release mortality"
    
    how_much_weight_exp <- 0.5 #1/num.exp.attributes 
    how_much_weight_sens <- 0.5 #1/num.sens.attributes 
    ###############################################################
    
    ###############################################################
    # ASSIGN WEIGHTS TO ATTRIBUTES
    
    df.tmp$Attribute.weighting <- NA
    df.tmp$Attribute.weighting[which(df.tmp$Attribute == higher_weight_exposure & df.tmp$Axis == "Exposure")] <- how_much_weight_exp
    df.tmp$Attribute.weighting[which(df.tmp$Attribute != higher_weight_exposure & df.tmp$Axis == "Exposure")] <- (1-how_much_weight_exp)/(num.exp.attributes -1)
    df.tmp$Attribute.weighting[which(df.tmp$Attribute == higher_weight_sensitivity & df.tmp$Axis == "Sensitivity")] <- how_much_weight_sens
    df.tmp$Attribute.weighting[which(df.tmp$Attribute != higher_weight_sensitivity & df.tmp$Axis == "Sensitivity")] <- (1-how_much_weight_sens)/(num.sens.attributes -1)
    ###############################################################
    
    ###############################################################
    # estimate average exposure and sensitivity scores for each ecosystem group, including baseline attributes
    df.tmp2 <-
      as.data.frame(
        df.tmp %>%
          group_by(Expert, Focal.component, Ecosystem.group, Fishery, Axis, Weighting) %>%
          summarise(
            Weighted.Mean = weighted.mean(Score, Attribute.weighting, na.rm=TRUE),
            Weighted.Data.Quality = weighted.mean(Data.Quality, Attribute.weighting, na.rm=TRUE)
            )
      )
    
  }
  ###############################################################
  
  ###############################################################
  ###############################################################
  
  ###############################################################
  #HABITAT. 
  # higher weight Sensitivity attribute Potential damage to habitat from fishing gear
  # exclude gear footprint attribute altogether
  ###############################################################
  
  if(df.tmp$Focal.component == "Habitat"){
    
    ###############################################################
    # DROP GEAR FOOTPRINT ATTRIBUTE
    if(exclude_gear == TRUE) {
      df.tmp <- df.tmp[-which(df.tmp$Attribute == "Gear footprint"),]
    }
    ###############################################################
    
    ###############################################################
    # CHANGE NAME OF MPA COVERAGE ATTRIBUTE
    df.tmp$Attribute <- as.character(df.tmp$Attribute)
    df.tmp$Attribute[which(df.tmp$Attribute == "MPA coverage and/or permanent spatial closures (RCA, gear closures)MPA coverage")] <- "MPA coverage"
    
    df.tmp$Axis[which(df.tmp$Attribute=="Current status")] <- "Sensitivity"
    ###############################################################
    
    ###############################################################
    # COUNT UP ATTRIBUTES
    num.exp.attributes <- length(unique( subset(df.tmp, Axis == "Exposure")$Attribute))
    num.sens.attributes <- length(unique( subset(df.tmp, Axis == "Sensitivity")$Attribute))
    ###############################################################
    
    
    ###############################################################
    # THIS IS ACTUALLY BEING USED TO GIVE 50% OF THE WEIGHT FOR THE EXPOSURE SCORE TO THIS ATTRIBUTE
    higher_weight_exposure <- "Gear footprint" #"MPA coverage"
    how_much_weight_exp <- 0.5 #1/num.exp.attributes 
    ###############################################################
    
    ###############################################################
    # THIS IS ACTUALLY BEING USED TO GIVE 50% OF THE WEIGHT FOR THE SENSITIVITY SCORE TO THIS ATTRIBUTE
    higher_weight_sensitivity <- "Potential damage to habitat from fishing gear"
    how_much_weight_sens <- 0.5 #1/num.sens.attributes 
    ###############################################################
    
    ###############################################################
    # ASSIGN WEIGHTS TO ATTRIBUTES
    df.tmp$Attribute.weighting <- NA
    df.tmp$Attribute.weighting[which(df.tmp$Attribute == higher_weight_exposure & df.tmp$Axis == "Exposure")] <- how_much_weight_exp
    df.tmp$Attribute.weighting[which(df.tmp$Attribute != higher_weight_exposure & df.tmp$Axis == "Exposure")] <- (1-how_much_weight_exp)/(num.exp.attributes -1)
    
    df.tmp$Attribute.weighting[which(df.tmp$Attribute == higher_weight_sensitivity & df.tmp$Axis == "Sensitivity")] <- how_much_weight_sens
    df.tmp$Attribute.weighting[which(df.tmp$Attribute != higher_weight_sensitivity & df.tmp$Axis == "Sensitivity")] <- (1-how_much_weight_sens)/(num.sens.attributes -1)
    
    ###############################################################
    
    # estimate average exposure and sensitivity scores for each ecosystem group, including baseline attributes
    df.tmp2 <-
      as.data.frame(
        df.tmp %>%
          group_by(Expert, Focal.component, Ecosystem.group, Fishery, Axis, Weighting, X..Habitat) %>%
          summarise(
            Weighted.Mean = weighted.mean(Score, Attribute.weighting, na.rm=TRUE),
            Weighted.Data.Quality = weighted.mean(Data.Quality, Attribute.weighting, na.rm=TRUE)
            )
      )
    
    }
  
  ###############################################################
  
  ###############################################################
  # REFORMAT RESULT TO WORK WITH OUTPUT DATA FRAME
  ###############################################################
  
  #df.tmp2_wide <- spread(df.tmp2, Axis, Weighted.Mean)
  df.tmp2_wide <- df.tmp2 %>%
  gather(variable, value, -(Ecosystem.group:Axis)) %>%
    unite(temp, Axis, variable) %>%
    spread(temp, value) %>%
    select(-Sensitivity_Expert, -Sensitivity_Focal.component, -Sensitivity_Weighting)
  
  X..Habitat <- ifelse(
    df.tmp2_wide$Exposure_Focal.component != "Habitat",
    rep(NA,nrow(df.tmp2_wide)),
    df.tmp2_wide$Exposure_X..Habitat
  )  # ignore warning messages about if(df.tmp2_wide$Focal.component != "Habitat")
  
  df.tmp2_wide <- cbind(
    df.tmp2_wide[,c("Exposure_Expert","Exposure_Focal.component","Ecosystem.group","Fishery","Exposure_Weighting")],
    X..Habitat,
    df.tmp2_wide[,c("Exposure_Weighted.Mean","Exposure_Weighted.Data.Quality","Sensitivity_Weighted.Mean","Sensitivity_Weighted.Data.Quality")]
  )

  colnames(df.tmp2_wide) <- c(
    "Expert", "Focal.component", "Ecosystem.group","Fishery",
    "Weighting", "X..Habitat", "Exposure_Weighted.Mean","Exposure_Weighted.Data.Quality","Sensitivity_Weighted.Mean","Sensitivity_Weighted.Data.Quality")
  
  ###############################################################
  
  ###############################################################
  # WRITE RESULTS TO OUTPUT DATA FRAME
  ###############################################################
  
  df.out <- rbind(df.out, df.tmp2_wide)
  
  ###############################################################
  
} # end for loop for scores files

###############################################################
# RENAME % HABITAT COLUMN
colnames(df.out)[6] <- "Percent.Habitat"
###############################################################

###############################################################
# CHECK THAT EVERYTHING LOOKS OK

head(df.out,10)
tail(df.out,10)
# head(df.out2,10)
# tail(df.out2,10)

# View(df.out[which(is.na(df.out$Sensitivity)),])
# View(df.out2[which(is.na(df.out2$Sensitivity)),])
###############################################################

###############################################################
# WRITE THE DF TO AN OUTPUT FILE
# Potential damage to habitat from fishing gear is weighted and gear footprint is excluded
###############################################################

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report")
#setwd("/Users/joe/Desktop/Jameal/Output files/Report")

write.csv(df.out,"Compiled scores including gear footprint Round_Final.csv", row.names=FALSE)

###############################################################

