library(ggplot2)
library(dplyr)
library(RColorBrewer)
library(ggrepel)

# theme to make pretty plots
setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Code")
source('theme_Publication.R')

##################################################################
### READ IN COMPILED INPUT DATA
##################################################################

# df.compiled_withB <- read.csv("/Users/joe/Dropbox/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)

##################################################
# use this line if gear footprint is excluded
##################################################
#df.compiled_withB <- read.csv("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)

##################################################
# use this line if gear footprint is included
##################################################
df.compiled_withB <- read.csv("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores including gear footprint Round_Final.csv", header=TRUE)

head(df.compiled_withB)

##################################################################
# FILTER TO BYCATCH ONLY
##################################################################

df.compiled_withB2 <-
  df.compiled_withB %>%
  filter(Focal.component == "Bycatch") 

##################################################################

##################################################################
# DO SOME CHECKS AND STORE SOME INFORMATION
##################################################################

n.bycatch.groups <- length(unique(df.compiled_withB2$Ecosystem.group))
n.fisheries <- length(unique(df.compiled_withB2$Fishery))

#as.vector(unique(df.compiled_withB2$Fishery))

df.compiled_withB2$Target.group <- ifelse(
  df.compiled_withB2$Fishery == "Sturgeon SHL", "WS",
  ifelse(df.compiled_withB2$Fishery == "Bass SHL", "KB",
         ifelse(df.compiled_withB2$Fishery == "Halibut SHL" | df.compiled_withB2$Fishery == "Halibut CTR" | df.compiled_withB2$Fishery == "Halibut CGN" | df.compiled_withB2$Fishery == "Halibut CHL", "CH",
                ifelse(df.compiled_withB2$Fishery == "Herring CGN", "PH",
                       ifelse(df.compiled_withB2$Fishery == "Lobster SH" | df.compiled_withB2$Fishery == "Lobster CTP", "SL",NA
                       )
                )
         )
  )
)

### DESIGNATE BYCATCH GROUPS WITH PROTECTED STATUS
#unique(df.compiled_withB2$Ecosystem.group)
protected <- c("Brd","Mam","TRk")
#df.compiled_withB2[which(df.compiled_withB2$Ecosystem.group == protected),]

##################################################################

#########################################################################
#########################################################################
### ### CALCULATE CONSENSUS SCORES FOR (1) EACH FISHERY-BYCATCH COMBINATION AND (2) ALL BYCATCH GROUPS FOR EACH FISHERY
##################################################################

#########################################################################
#########################################################################
### CALCULATE CONSENSUS SCORES FOR (1) EACH FISHERY-BYCATCH COMBINATION
#########################################################################

df.consensus_withB2 <-
  as.data.frame(
  df.compiled_withB2 %>%
  group_by(Ecosystem.group, Fishery) %>% 
  summarise(Mean.Exposure = mean(Exposure_Weighted.Mean, na.rm=TRUE), Mean.Sensitivity = mean(Sensitivity_Weighted.Mean, na.rm=TRUE))
  )
head(df.consensus_withB2)

df.consensus2_withB2 <- df.consensus_withB2

#########################################################################
#########################################################################
### CALCULATE CONSENSUS SCORES FOR (2) ALL BYCATCH GROUPS FOR EACH FISHERY BASED ON (A) EQUAL WEIGHTING OF BYCATCH GROUPS TO GENERATE AN AVERAGE, AND (B) CUMULATIVE EXPOSURE AND SENSITIVITY SCORES GENERATED BY SUMMING ACROSS BYCATCH GROUPS
#########################################################################

#########################################################################
# (A) EQUAL WEIGHTING OF BYCATCH GROUPS TO GENERATE AN AVERAGE
#########################################################################
all.tmp_withB_equal_weighting <-     
  as.data.frame(
  df.consensus_withB2 %>%
  group_by(Fishery) %>%
  summarise(Equal.Weighting.Mean.All.Exposure = mean(Mean.Exposure, na.rm=TRUE), 
            Equal.Weighting.Mean.All.Sensitivity = mean(Mean.Sensitivity, na.rm=TRUE)
  )
  )
# change Fishery from factor to character
all.tmp_withB_equal_weighting$Fishery <-as.character(all.tmp_withB_equal_weighting$Fishery)

# ADD ECOSYSTEM GROUP CALLED ALL BYCATCH AND make compatible with data frame produced in (1) df.consensus2_withB2
all.tmp_withB_equal_weighting <- data.frame(
  rep("All.Bycatch",nrow(all.tmp_withB_equal_weighting)), # change to All.Habitats
  all.tmp_withB_equal_weighting[,'Fishery'], 
  all.tmp_withB_equal_weighting[,c('Equal.Weighting.Mean.All.Exposure','Equal.Weighting.Mean.All.Sensitivity')]
  )
colnames(all.tmp_withB_equal_weighting) <- c("Ecosystem.group", "Fishery","Mean.Exposure", "Mean.Sensitivity")

# combine two data frames into 1
df.consensus3_withB2 <- rbind(df.consensus2_withB2, all.tmp_withB_equal_weighting)
#########################################################################

#########################################################################
#(B) CUMULATIVE EXPOSURE AND SENSITIVITY SCORES GENERATED BY SUMMING ACROSS BYCATCH GROUPS
#########################################################################

df.consensus3_withB2_cumulative <-
  as.data.frame(
  df.consensus2_withB2 %>%
  group_by(Fishery) %>%
  summarise(Cum.Exposure.All.Bycatch = sum(Mean.Exposure, na.rm=TRUE),
            Cum.Sensitivity.All.Bycatch = sum(Mean.Sensitivity, na.rm=TRUE),
            Num.Bycatch.Groups = length(which(is.na(Mean.Exposure)==FALSE)),
            Num.Protected.Groups = length(which(is.na(Mean.Exposure)==FALSE & is.na(match(Ecosystem.group,protected))==FALSE))
  )
  )

#########################################################################

#########################################################################
#########################################################################
### ADD COLUMN FOR RISK SCORE
#########################################################################

df.consensus3_withB2$Mean.Risk <- sqrt(
  (df.consensus3_withB2$Mean.Exposure-1)^2 +
    (df.consensus3_withB2$Mean.Sensitivity - 1)^2
)

df.consensus3_withB2_cumulative$Cum.Risk.All.Bycatch <- sqrt(
  (df.consensus3_withB2_cumulative$Cum.Exposure.All.Bycatch-1)^2 +
    (df.consensus3_withB2_cumulative$Cum.Sensitivity.All.Bycatch - 1)^2
)

#########################################################################



##################################################################################################################################################
# write out .csv file with summary exposure and sensitivity scores
#########################################################################


setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Bycatch")

##################################################
# use these lines if gear footprint is excluded
##################################################
# write.csv(df.consensus3_withB2, "Exposure and sensitivity scores for individual Bycatch groups and all Bycatch groups averaged with equal weights Round_Final.csv", row.names = FALSE) 
# write.csv(df.consensus3_withB2_cumulative,"Cumulative exposure and sensitivity scores for Bycatch groups Round_Final.csv", row.names = FALSE)

##################################################
# use these lines if gear footprint is included
##################################################
write.csv(df.consensus3_withB2, "Exposure and sensitivity scores for individual Bycatch groups and all Bycatch groups averaged with equal weights including gear footprint Round_Final.csv", row.names = FALSE) 
write.csv(df.consensus3_withB2_cumulative,"Cumulative exposure and sensitivity scores for Bycatch groups including gear footprint Round_Final.csv", row.names = FALSE)
#########################################################################


#########################################################################
#########################################################################
## MAKE RISK PLOTS BASE LAYER WITH CONTOUR LINES
#########################################################################

## CREATE A MATRIX OF XYZ POINTS
faux = seq(1,4,length.out=100)
a=expand.grid(faux,faux)
b = matrix(sqrt((a[,1]-1)^2 + (a[,2]-1)^2),100)
riskcontour = data.frame(cbind(a,as.vector(b)))
names(riskcontour) = c("E","S","R")
head(riskcontour)

## MAKE THE HEAT MAP USING GEOM_TILE
mycolor <- ggplot(riskcontour) + geom_raster(aes(x=E,y=S,fill=R)) + scale_fill_gradientn("Relative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100)) + xlab("Exposure") + ylab("Sensitivity") + 
  theme(
    text=element_text(size=14),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_rect(fill = NA,colour = "black",size=2)
  ) 

## Add contour lines to heat map
riskbg <- mycolor + stat_contour(aes(x = E, y = S, z = R),linetype="dotted",colour="darkslategrey") 
riskbg

# cumulative risk background
## CREATE A MATRIX OF XYZ POINTS
max.cum = 24 #4*n.bycatch.groups
faux2 = seq(1,max.cum,length.out=100)
a2=expand.grid(faux2,faux2)
b2 = matrix(sqrt((a2[,1]-1)^2 + (a2[,2]-1)^2),100)
riskcontour.cum = data.frame(cbind(a2,as.vector(b2)))
names(riskcontour.cum) = c("E","S","R")
head(riskcontour.cum)

## MAKE THE HEAT MAP USING GEOM_TILE
mycolor.cum <- ggplot(riskcontour.cum) + geom_raster(aes(E,S,fill=R)) + 
  scale_fill_gradientn("Relative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100)) +  
  xlab("Exposure") + ylab("Sensitivity") + 
    theme(
  text=element_text(size=14),
  panel.grid.major = element_blank(),
  panel.grid.minor = element_blank(),
  panel.background = element_rect(fill = NA,colour = "black",size=2)
) 

## Add contour lines to heat map
riskbg.cum <- mycolor.cum + stat_contour(aes(x = E, y = S, z = R),linetype="dotted",colour="darkslategrey") 
riskbg.cum

#########################################################################


#########################################################################
#########################################################################
## MAKE RISK PLOTS BY FISHERY, INCUDING CUMULATIVE RISK ACROSS BYCATCH GROUPS AMD FISHERIES 
#########################################################################

# drop All.Bycatch group
df.consensus3_withB2_individual_groups <- df.consensus3_withB2[-which(df.consensus3_withB2$Ecosystem.group == "All.Bycatch"),]

#########################################################################
# EACH FISHERY-BYCATCH COMBINATION, EACH PANEL IS A FISHERY EACH POINT IS A BYCATCH GROUP

risk_by_fishery_TrueOnes <- riskbg + 
  geom_text_repel(data=df.consensus3_withB2_individual_groups, aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Ecosystem.group), size=4) +
  geom_point(data=df.consensus3_withB2_individual_groups, aes(x=Mean.Exposure,y=Mean.Sensitivity))+
  facet_wrap(~Fishery) + 
  theme_Publication()
risk_by_fishery_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Bycatch")
#pdf("risk panels by fishery for individual bycatch groups Round_Final figure.pdf", width=10, height=8)
pdf("risk panels by fishery for individual bycatch groups including gear footprint Round_Final figure.pdf", width=10, height=8)
risk_by_fishery_TrueOnes
dev.off()

#########################################################################
# EACH FISHERY-BYCATCH COMBINATION, EACH PANEL IS A BYCATCH GROUP EACH POINT IS A FISHERY GROUP

risk_by_bycatch_group_TrueOnes <- riskbg + 
  geom_text_repel(data=df.consensus3_withB2_individual_groups, aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery), size=4) +
  geom_point(data=df.consensus3_withB2_individual_groups, aes(x=Mean.Exposure,y=Mean.Sensitivity))+
  facet_wrap(~Ecosystem.group) + 
  theme_Publication()
risk_by_bycatch_group_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Bycatch")
#pdf("risk panels by bycatch group for individual fisheries Round_Final figure.pdf", width=10, height=8)
pdf("risk panels by bycatch group for individual fisheries including gear footprint Round_Final figure.pdf", width=10, height=8)
risk_by_bycatch_group_TrueOnes
dev.off()

#########################################################################


#########################################################################
# MAKE ALL BYCATCH RISK PLOTS WITH EQUAL WEIGHTING OF BYCATCH GROUPS TO GENERATE AN AVERAGE

# make all bycatch df
df.allbycatch_TrueOnes <- df.consensus3_withB2[-which(df.consensus3_withB2$Ecosystem.group != "All.Bycatch"),]

risk_by_ALL.BYCATCH_TrueOnes <- riskbg + geom_text_repel(data=df.allbycatch_TrueOnes, aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery), size=6) +
  geom_point(data=df.allbycatch_TrueOnes, aes(x=Mean.Exposure,y=Mean.Sensitivity))+
  theme_Publication()
risk_by_ALL.BYCATCH_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Bycatch")
#pdf("risk to all bycatch groups (averaged with equal weights) due to each fishery figure.pdf", width=10, height=8)
pdf("risk to all bycatch groups (averaged with equal weights) due to each fishery including gear footprint figure.pdf", width=10, height=8)
risk_by_ALL.BYCATCH_TrueOnes
dev.off()

#########################################################################
## MAKE CUMULATIVE RISK PLOTS ACROSS FISHERIES

risk_by_ALL.BYCATCH_TrueOnes_cumulative <- riskbg.cum + geom_text_repel(data=df.consensus3_withB2_cumulative, aes(x=Cum.Exposure.All.Bycatch,y=Cum.Sensitivity.All.Bycatch,label=Fishery), size=6) +
  geom_point(data=df.consensus3_withB2_cumulative, aes(x=Cum.Exposure.All.Bycatch,y=Cum.Sensitivity.All.Bycatch, size=factor(Num.Protected.Groups)))+
  scale_size_manual(values=c(2,4,6))+
  xlim(1,20)+ylim(1,20)+
  xlab("Exposure") + ylab("Sensitivity") + 
  labs(size="Number of affected\n protected groups") +
  theme_Publication()
risk_by_ALL.BYCATCH_TrueOnes_cumulative

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Bycatch")
#pdf("Cumulative risk to all bycatch groups due to each fishery figure.pdf", width=10, height=8)
pdf("Cumulative risk to all bycatch groups due to each fishery including gear footprint figure.pdf", width=10, height=8)
risk_by_ALL.BYCATCH_TrueOnes_cumulative
dev.off()


#########################################################################
################################
################################
################################
################################
################################
################################
################################
################################

### GRAVEYARD


