library(ggplot2)
library(dplyr)
library(RColorBrewer)
library(ggrepel)

# theme to make pretty plots
setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Code")
source('theme_Publication.R')

##################################################################
### READ IN COMPILED INPUT DATA
##################################################################

# df.compiled_withB <- read.csv("/Users/joe/Dropbox/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)

##################################################
# use this line if gear footprint is excluded
##################################################
#df.compiled_withB <- read.csv("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)

##################################################
# use this line if gear footprint is included
##################################################
df.compiled_withB <- read.csv("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores including gear footprint Round_Final.csv", header=TRUE)

##################################################################
# FILTER TO HABITAT ONLY
##################################################################
df.compiled_withB2 <-
  df.compiled_withB %>%
  filter(Focal.component == "Habitat")

##################################################################

##################################################################
# DO SOME CHECKS AND STORE SOME INFORMATION
##################################################################

n.habitat.groups <- length(unique(df.compiled_withB2$Ecosystem.group)) # 
n.fisheries <- length(unique(df.compiled_withB2$Fishery))

#as.vector(unique(df.compiled_withB2$Fishery))

df.compiled_withB2$Target.group <- ifelse(
  df.compiled_withB2$Fishery == "Sturgeon SHL", "WS",
  ifelse(df.compiled_withB2$Fishery == "Bass SHL", "KB",
         ifelse(df.compiled_withB2$Fishery == "Halibut SHL" | df.compiled_withB2$Fishery == "Halibut CTR" | df.compiled_withB2$Fishery == "Halibut CGN" | df.compiled_withB2$Fishery == "Halibut CHL", "CH",
                ifelse(df.compiled_withB2$Fishery == "Herring CGN", "PH",
                       ifelse(df.compiled_withB2$Fishery == "Lobster SH" | df.compiled_withB2$Fishery == "Lobster CTP", "SL",NA
                       )
                )
         )
  )
)

##################################################################

#########################################################################
#########################################################################
### ### CALCULATE CONSENSUS SCORES FOR (1) EACH FISHERY-HABITAT COMBINATION AND (2) ALL HABITAT GROUPS FOR EACH FISHERY
##################################################################

#########################################################################
#########################################################################
### CALCULATE CONSENSUS SCORES FOR (1) EACH FISHERY-HABITAT COMBINATION
#########################################################################

df.consensus_withB2 <-
  as.data.frame(
    df.compiled_withB2 %>%
      group_by(Ecosystem.group, Fishery, Percent.Habitat) %>% 
      summarise(Mean.Exposure = mean(Exposure_Weighted.Mean, na.rm=TRUE), Mean.Sensitivity = mean(Sensitivity_Weighted.Mean, na.rm=TRUE))
  )
head(df.consensus_withB2)

df.consensus2_withB2 <- df.consensus_withB2

#########################################################################

#########################################################################
#########################################################################
### CALCULATE CONSENSUS SCORES FOR (2) ALL HABITAT GROUPS FOR EACH FISHERY BASED ON (A) CDFW EXPERT-BASED WEIGHTING OF HABITAT GROUPS TO GENERATE AN AVERAGE
#########################################################################

#########################################################################
# (A) CDFW EXPERT-BASED WEIGHTING OF HABITAT GROUPS TO GENERATE AN AVERAGE
#########################################################################
all.tmp_withB_CDFW_weighting <-     
  as.data.frame(
    df.consensus_withB2 %>%
      group_by(Fishery) %>%
      summarise(CDFW.Weighting.Mean.All.Exposure = weighted.mean(Mean.Exposure, Percent.Habitat, na.rm=TRUE), 
                CDFW.Weighting.Mean.All.Sensitivity = weighted.mean(Mean.Sensitivity, Percent.Habitat, na.rm=TRUE)
      )
  )

# change Fishery from factor to character
all.tmp_withB_CDFW_weighting$Fishery <-as.character(all.tmp_withB_CDFW_weighting$Fishery)

# ADD ECOSYSTEM GROUP CALLED ALL HABITATS AND make compatible with data frame produced in (1) df.consensus2_withB2
all.tmp_withB_CDFW_weighting <- data.frame(
  rep("All.Habitats",nrow(all.tmp_withB_CDFW_weighting)), # change to All.Habitats
  all.tmp_withB_CDFW_weighting[,'Fishery'], 
  all.tmp_withB_CDFW_weighting[,c('CDFW.Weighting.Mean.All.Exposure','CDFW.Weighting.Mean.All.Sensitivity')]
)
colnames(all.tmp_withB_CDFW_weighting) <- c("Ecosystem.group", "Fishery","Mean.Exposure", "Mean.Sensitivity")

#########################################################################

# make an all habitats data frame. add column for number of habitats
# number of habitats
n.habitats.by.fishery <-
  as.data.frame(
    df.consensus_withB2 %>%
  group_by(Fishery) %>%
  summarise(N.Habitats = length(which(Percent.Habitat >0)))
  )

df.consensus3_withB2_all <-
  cbind(
    all.tmp_withB_CDFW_weighting,
    n.habitats.by.fishery
  )
  

#########################################################################
#########################################################################
### ADD COLUMN FOR RISK SCORE
#########################################################################

df.consensus3_withB2_all$Mean.Risk <- sqrt(
  (df.consensus3_withB2_all$Mean.Exposure-1)^2 +
    (df.consensus3_withB2_all$Mean.Sensitivity - 1)^2
)

#########################################################################

##################################################################################################################################################
# write out .csv file with summary exposure and sensitivity scores
#########################################################################


setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Habitat")

##################################################
# use this line if gear footprint is excluded
##################################################
# write.csv(df.consensus2_withB2, "Exposure and sensitivity scores for individual Habitat groups Round_Final.csv", row.names = FALSE) 
# write.csv(df.consensus3_withB2_all,"Exposure and sensitivity scores for All Habitat groups averaged with equal weights Round_Final.csv", row.names = FALSE)

##################################################
# use this line if gear footprint is included
##################################################
write.csv(df.consensus2_withB2, "Exposure and sensitivity scores for individual Habitat groups gear footprint included Round_Final.csv", row.names = FALSE)
write.csv(df.consensus3_withB2_all,"Exposure and sensitivity scores for All Habitat groups averaged with equal weights gear footprint included Round_Final.csv", row.names = FALSE)

#########################################################################


#########################################################################
#########################################################################
## MAKE RISK PLOTS BASE LAYER WITH CONTOUR LINES
#########################################################################

## CREATE A MATRIX OF XYZ POINTS
faux = seq(1,4,length.out=100)
a=expand.grid(faux,faux)
b = matrix(sqrt((a[,1]-1)^2 + (a[,2]-1)^2),100)
riskcontour = data.frame(cbind(a,as.vector(b)))
names(riskcontour) = c("E","S","R")
head(riskcontour)

## MAKE THE HEAT MAP USING GEOM_TILE
mycolor <- ggplot(riskcontour) + geom_raster(aes(x=E,y=S,fill=R)) + scale_fill_gradientn("Relative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100)) + xlab("Exposure") + ylab("Sensitivity") + 
  theme(
    text=element_text(size=14),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_rect(fill = NA,colour = "black",size=2)
  ) 

## Add contour lines to heat map
riskbg <- mycolor + stat_contour(aes(x = E, y = S, z = R),linetype="dotted",colour="darkslategrey") 
riskbg


#########################################################################

#########################################################################
#########################################################################
## MAKE RISK PLOTS BY FISHERY, INCUDING CUMULATIVE RISK ACROSS HABITAT GROUPS AMD FISHERIES 
#########################################################################

#########################################################################
# EACH FISHERY-HABITAT COMBINATION, EACH PANEL IS A FISHERY EACH POINT IS A HABITAT GROUP

risk_by_fishery_TrueOnes <- riskbg + 
  geom_text_repel(data=df.consensus2_withB2, aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Ecosystem.group), size=4) +
  geom_point(data=df.consensus2_withB2, aes(x=Mean.Exposure,y=Mean.Sensitivity))+
  facet_wrap(~Fishery) + 
  theme_Publication()
risk_by_fishery_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Habitat")
# pdf("risk panels by fishery for individual habitat groups Round_Final figure.pdf", width=10, height=8)
pdf("risk panels by fishery for individual habitat groups gear footprint included Round_Final figure.pdf", width=10, height=8)
risk_by_fishery_TrueOnes
dev.off()

#########################################################################
# EACH FISHERY-HABITAT COMBINATION, EACH PANEL IS A HABITAT GROUP EACH POINT IS A FISHERY GROUP

risk_by_habitat_group_TrueOnes <- riskbg + 
  geom_text_repel(data=df.consensus2_withB2, aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery), size=4) +
  geom_point(data=df.consensus2_withB2, aes(x=Mean.Exposure,y=Mean.Sensitivity))+
  facet_wrap(~Ecosystem.group) + 
  theme_Publication()
risk_by_habitat_group_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Habitat")
# pdf("risk panels by habitat group for individual fisheries Round_Final figure.pdf", width=10, height=8)
pdf("risk panels by habitat group for individual fisheries gear footprint included Round_Final figure.pdf", width=10, height=8)
risk_by_habitat_group_TrueOnes
dev.off()

#########################################################################
# MAKE ALL HABITATS RISK PLOTS WITH CDFW WEIGHTING OF HABITAT GROUPS TO GENERATE AN AVERAGE

risk_by_ALL.HABITATS_TrueOnes <- riskbg + 
  geom_text_repel(
    data=df.consensus3_withB2_all, aes(
      x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery
      ), size=6
    ) +
  geom_point(
    data=df.consensus3_withB2_all, aes(
      x=Mean.Exposure,y=Mean.Sensitivity, size=factor(N.Habitats)
      )
    )+
  scale_size_manual(values=c(2,4,6,8))+
  scale_fill_gradientn("Weighted Average\nRelative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100)) +  
  scale_colour_gradientn("Weighted Average\nRelative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100))+
  labs(size="Number of affected\n habitat groups") +
  theme_Publication()
risk_by_ALL.HABITATS_TrueOnes

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Habitat")
# pdf("risk to all habitat groups (averaged with CDFW weights) due to each fishery figure.pdf", width=10, height=8)
pdf("risk to all habitat groups (averaged with CDFW weights) due to each fishery gear footprint included figure.pdf", width=10, height=8)
risk_by_ALL.HABITATS_TrueOnes
dev.off()


#########################################################################

################################
################################
################################
################################
################################
################################
################################
################################

### GRAVEYARD


