library(ggplot2)
library(dplyr)
library(RColorBrewer)
library(ggrepel)

# read in theme to make pretty plots
setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Code")
source('theme_Publication.R')


##################################################################
### READ IN COMPILED INPUT DATA
##################################################################

# df.compiled_withB <- read.csv("/Users/joe/Dropbox/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)
df.compiled_withB <- read.csv("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Compiled scores Round_Final.csv", header=TRUE)
head(df.compiled_withB)

##################################################################
# FILTER TO TARGET ONLY
##################################################################

df.compiled_withB2 <-
  df.compiled_withB %>%
  filter(Focal.component == "Target") 

##################################################################

##################################################################
# DO SOME CHECKS AND STORE SOME INFORMATION
##################################################################

n.target.groups <- length(unique(df.compiled_withB2$Ecosystem.group))
n.fisheries <- length(unique(df.compiled_withB2$Fishery))

df.compiled_withB2$Target.group <- ifelse(
  df.compiled_withB2$Fishery == "Sturgeon SHL", "WS",
  ifelse(df.compiled_withB2$Fishery == "Bass SHL", "KB",
         ifelse(df.compiled_withB2$Fishery == "Halibut SHL" | df.compiled_withB2$Fishery == "Halibut CTR" | df.compiled_withB2$Fishery == "Halibut CGN" | df.compiled_withB2$Fishery == "Halibut CHL", "CH",
                ifelse(df.compiled_withB2$Fishery == "Herring CGN", "PH",
                       ifelse(df.compiled_withB2$Fishery == "Lobster SH" | df.compiled_withB2$Fishery == "Lobster CTP", "SL",NA
                       )
                )
         )
  )
)

##################################################################

#########################################################################
#########################################################################
### CALCULATE CONSENSUS SCORES FOR (1) EACH FISHERY-TARGET COMBINATION, 
#########################################################################
 
df.consensus_withB2 <-
  as.data.frame(
    df.compiled_withB2 %>%
      group_by(Ecosystem.group, Fishery, Weighting) %>%
      summarise(Mean.Exposure = mean(Exposure_Weighted.Mean, na.rm=TRUE), Mean.Sensitivity = mean(Sensitivity_Weighted.Mean, na.rm=TRUE),
                Mean.Exposure.Data.Quality = mean(Exposure_Weighted.Data.Quality, na.rm=TRUE),
                Mean.Sensitivity.Data.Quality = mean(Sensitivity_Weighted.Data.Quality, na.rm=TRUE)
                )
  )
df.consensus_withB2

df.consensus2_withB2 <- df.consensus_withB2

### ADD COLUMN FOR RISK SCORE AND RISK DATA QUALITY
df.consensus2_withB2$Mean.Risk <- sqrt(
  (df.consensus2_withB2$Mean.Exposure-1)^2 +
    (df.consensus2_withB2$Mean.Sensitivity - 1)^2
)

df.consensus2_withB2$Risk.Data.Quality <- 
  (df.consensus2_withB2$Mean.Exposure.Data.Quality+df.consensus2_withB2$Mean.Sensitivity.Data.Quality)/2

### create pretty labels
df.consensus2_withB2$Pretty.Ecosystem.Group <- c(
  "Kelp Bass", rep("California Halibut",4), "Pacific Herring",rep("Spiny Lobster",2),"White Sturgeon"
  )

#########################################################################
#########################################################################
# write out .csv file with summary exposure and sensitivity scores
#########################################################################

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Target")
write.csv(df.consensus2_withB2, "Exposure and sensitivity scores for Target groups Round_Final.csv", row.names = FALSE) 



#########################################################################
#########################################################################
## MAKE RISK PLOTS BASE LAYER WITH CONTOUR LINES
#########################################################################

## CREATE A MATRIX OF XYZ POINTS
faux = seq(1,4,length.out=100)
a=expand.grid(faux,faux)
b = matrix(sqrt((a[,1]-1)^2 + (a[,2]-1)^2),100)
riskcontour = data.frame(cbind(a,as.vector(b)))
names(riskcontour) = c("E","S","R")
head(riskcontour)

## MAKE THE HEAT MAP USING GEOM_TILE
mycolor <- ggplot(riskcontour) + geom_raster(aes(x=E,y=S,fill=R)) + scale_fill_gradientn("Relative Risk",colours=colorRampPalette(brewer.pal(9,"Blues"))(100)) + xlab("Exposure") + ylab("Sensitivity") + 
  theme(
  text=element_text(size=14),
  panel.grid.major = element_blank(),
  panel.grid.minor = element_blank(),
  panel.background = element_rect(fill = NA,colour = "black",size=2)
) 

## Add contour lines to heat map
riskbg <- mycolor + stat_contour(aes(x = E, y = S, z = R),linetype="dotted",colour="darkslategrey") 
riskbg

#########################################################################
#########################################################################
## MAKE RISK PLOTS BY FISHERY WITHOUT DATA QUALITY REPRESENTED
#########################################################################

risk_by_fishery <- riskbg + 
  geom_text_repel(data=df.consensus2_withB2[1:n.fisheries,], aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery), size=6) +
  geom_point(data=df.consensus2_withB2[1:n.fisheries,], aes(x=Mean.Exposure,y=Mean.Sensitivity), size=4)+
  theme_Publication()
risk_by_fishery

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Target")
pdf("risk by fishery for target groups WITHOUT DATA QUALITY Round_Final figure.pdf", width=10, height=8)#, units="in", res=500)
risk_by_fishery
dev.off()

#########################################################################

#########################################################################
#########################################################################
## MAKE RISK PLOTS BY FISHERY WITH DATA QUALITY REPRESENTED
#########################################################################

risk_by_fishery_DQ <- riskbg + 
  geom_text_repel(data=df.consensus2_withB2[1:n.fisheries,], aes(x=Mean.Exposure,y=Mean.Sensitivity,label=Fishery), size=6) +
  geom_point(data=df.consensus2_withB2[1:n.fisheries,], aes(x=Mean.Exposure,y=Mean.Sensitivity, colour = factor(ceiling(Risk.Data.Quality))), size=4)+
  scale_colour_grey(end=0.1,start=0.9)+
  labs(colour="Data quality\n (ceiling)")+
  theme_Publication()
risk_by_fishery_DQ

setwd("~/Dropbox/Projects/In progress/Samhouri et al. ecosystem risk assessment for the effects of fishing in California/OST prioritizing stock assessments/Risk tool/Output files/Report/Target")
pdf("risk by fishery for target groups WITH DATA QUALITY Round_Final figure.pdf", width=10, height=8)#, units="in", res=500)
risk_by_fishery_DQ
dev.off()

#########################################################################




################################
################################
################################
################################
################################
################################
################################
################################

### GRAVEYARD


